@@ -28,7 +28,7 @@ struct DearmorReady<'a> {
     data: &'a mut (dyn Read + Send + Sync),
 }
 
-impl<'a> sop::ops::Ready for DearmorReady<'a> {
+impl sop::ops::Ready for DearmorReady<'_> {
     fn to_writer(self: Box<Self>, mut sink: &mut (dyn Write + Send + Sync)) -> sop::Result<()> {
         let mut reader = BufReader::new(self.data);
 
