@@ -7,8 +7,9 @@ use pgp::cleartext::CleartextSignedMessage;
 use pgp::packet::{LiteralData, Packet};
 use pgp::ser::Serialize;
 use pgp::types::PublicKeyTrait;
-use pgp::{ArmorOptions, Deserializable, Message};
-use rpgpie::key::DataSigner;
+use pgp::{ArmorOptions, Deserializable, Message, Signature};
+use rpgpie::tsk::DataSigner;
+use sop::errors::Error;
 
 use crate::cmd::sign::Sign;
 use crate::{Keys, RPGSOP};
@@ -67,11 +68,11 @@ impl<'a> sop::ops::InlineSign<'a, RPGSOP, Keys> for InlineSign {
         'a: 'd,
     {
         if self.sign.signers.is_empty() {
-            return Err(sop::errors::Error::MissingArg);
+            return Err(Error::MissingArg);
         }
 
         if !self.armor && matches!(self.mode, sop::ops::InlineSignAs::ClearSigned) {
-            return Err(sop::errors::Error::IncompatibleOptions);
+            return Err(Error::IncompatibleOptions);
         }
 
         Ok(Box::new(InlineSignReady {
@@ -86,7 +87,7 @@ struct InlineSignReady<'a> {
     data: &'a mut (dyn io::Read + Send + Sync),
 }
 
-impl<'a> sop::ops::Ready for InlineSignReady<'a> {
+impl sop::ops::Ready for InlineSignReady<'_> {
     fn to_writer(self: Box<Self>, mut sink: &mut (dyn io::Write + Send + Sync)) -> sop::Result<()> {
         let mut data = vec![];
         self.data.read_to_end(&mut data)?;
@@ -113,7 +114,7 @@ impl<'a> sop::ops::Ready for InlineSignReady<'a> {
                 .collect()
         };
 
-        let mut signers: Vec<DataSigner> = vec![];
+        let mut datasigners: Vec<DataSigner> = vec![];
         for tsk in self.inline_sign.sign.signers {
             let mut s: Vec<DataSigner> = tsk.signing_capable_component_keys().collect();
 
@@ -124,43 +125,66 @@ impl<'a> sop::ops::Ready for InlineSignReady<'a> {
                 );
             }
 
-            signers.append(&mut s);
+            datasigners.append(&mut s);
         }
 
         let lit = match &self.inline_sign.mode {
             sop::ops::InlineSignAs::Binary => LiteralData::from_bytes("".into(), &data),
             sop::ops::InlineSignAs::Text => {
-                LiteralData::from_str("", &String::from_utf8(data).expect("FIXME"))
+                LiteralData::from_str("", &String::from_utf8(data).map_err(|_| Error::BadData)?)
             }
             sop::ops::InlineSignAs::ClearSigned => {
-                let body = String::from_utf8(data).expect("foo");
+                let signers = |text: &[u8]| {
+                    let lit = Message::Literal(LiteralData::from_str(
+                        [],
+                        core::str::from_utf8(text).map_err(|_| {
+                            pgp::errors::Error::Message("Data is not UTF-8".to_string())
+                        })?,
+                    ));
 
-                let s: Vec<_> = signers.into_iter().map(|s| (s, pws.as_slice())).collect();
+                    let mut sigs: Vec<Signature> = vec![];
 
-                // FIXME: This all is awkward and inefficient.
-                // We shouldn't use `ds.sign_csf`, and instead use a separate pure data signing function
+                    for ds in datasigners {
+                        let mut sig = None;
 
-                // We don't use the `_text` input to the closure, but instead let `ds.sign_csf`
-                // normalize `body` for each signature.
+                        // try all passwords for this DataSigner
+                        'pws: for pw in &pws {
+                            let res = ds.sign_msg(
+                                lit.clone(),
+                                || String::from_utf8_lossy(pw).to_string(),
+                                hash_algo,
+                            );
 
-                let signers = |_text: &[u8]| {
-                    let mut sigs = vec![];
+                            if let Ok(Message::Signed { signature, .. }) = res {
+                                sig = Some(signature);
+                                break 'pws; // we found a working password for ds, stop trying more
+                            }
+                        }
 
-                    for x in s {
-                        let (ds, pw) = &x;
+                        if let Some(s) = sig {
+                            sigs.push(s);
+                        } else {
+                            // We failed to produce a signature, for some reason.
+                            // Maybe it's password protection.
+                            // TODO: return a more concrete error?
 
-                        let csf = ds.sign_csf(&body, pw).expect("FIXME");
-                        let s = csf.signatures();
-                        sigs.push(s[0].signature.clone());
+                            return Err(pgp::errors::Error::Message("Couldn't sign".into()));
+                        }
                     }
 
                     Ok(sigs)
                 };
 
-                let csf = CleartextSignedMessage::new_many(&body, signers).expect("FIXME");
+                let text = core::str::from_utf8(&data).map_err(|_| Error::BadData)?;
+                let Ok(csf) = CleartextSignedMessage::new_many(text, signers) else {
+                    // The signers failed, for some reason. It might be password protection.
+                    // TODO: Check error conditions more closely, and return more specific errors.
+
+                    return Err(Error::KeyIsProtected);
+                };
 
                 csf.to_armored_writer(&mut sink, ArmorOptions::default())
-                    .expect("FIXME");
+                    .expect("writing failed");
 
                 return Ok(());
             }
@@ -171,11 +195,11 @@ impl<'a> sop::ops::Ready for InlineSignReady<'a> {
 
         let lit_msg = Message::Literal(lit);
 
-        for signer in signers {
+        for ds in datasigners {
             let sig = pws
                 .iter()
                 .flat_map(|pw| {
-                    signer.sign_msg(
+                    ds.sign_msg(
                         lit_msg.clone(),
                         || String::from_utf8_lossy(pw).to_string(),
                         hash_algo,
@@ -202,20 +226,26 @@ impl<'a> sop::ops::Ready for InlineSignReady<'a> {
                     packets.push(Packet::from(signature));
                 }
             } else {
-                panic!("foo");
+                // We failed to produce a signature, for some reason.
+                // Probably it's password protection.
+                // TODO: make sure that password locking was actually the problem.
+
+                return Err(Error::KeyIsProtected);
             }
         }
 
         let signed = Message::from_packets(packets.into_iter().map(Ok).peekable())
             .next()
-            .expect("should be a message")
-            .expect("FIXME");
+            .unwrap_or(Err(pgp::errors::Error::Message(
+                "parser couldn't construct a message".to_string(),
+            )))
+            .map_err(|_| Error::UnspecifiedFailure)?; // failed to construct a message
 
         match self.inline_sign.armor {
             true => signed
                 .to_armored_writer(&mut sink, ArmorOptions::default())
-                .expect("FIXME"),
-            false => signed.to_writer(&mut sink).expect("FIXME"),
+                .expect("writing failed"),
+            false => signed.to_writer(&mut sink).expect("writing failed"),
         }
 
         Ok(())
