@@ -20,13 +20,19 @@ impl sop::ops::Version<'_> for Version {
     fn backend(&self) -> sop::Result<sop::ops::VersionInfo> {
         Ok(sop::ops::VersionInfo {
             name: "rpgpie".into(),
-            version: format!("{} (rpgp {})", rpgpie::VERSION, rpgpie::RPGP_VERSION),
+            version: rpgpie::VERSION.into(),
         })
     }
 
     fn extended(&self) -> sop::Result<String> {
+        #[cfg(feature = "unstable-curve448")]
+        let c448 = "yes";
+        #[cfg(not(feature = "unstable-curve448"))]
+        let c448 = "no";
+
         Ok([
             format!("rpgpie {}", rpgpie::VERSION),
+            format!("unstable-448: {}", c448),
             format!("rpgp {}", rpgpie::RPGP_VERSION),
         ]
         .join("\n"))
